import type { APIRoute } from 'astro';
import { db } from '@db/database.ts';
import { API_SECRET } from 'astro:env/server';

export const GET: APIRoute = async ({ request }) => {
  if (API_SECRET && request.headers.get('authorization') !== `Basic ${API_SECRET}`) {
    return new Response(null, { status: 401 });
  }

  const teams = await db.getTeamsFull({});

  const response = {} as Record<number, any>;
  for (const team of teams) {
    if (response[team.team.id] === undefined) {
      response[team.team.id] = {
        name: team.team.name,
        color: team.team.color,
        lastJoined: team.team.lastJoined ? new Date(team.team.lastJoined).getTime() : null,
        strikeWeight: team.strikeWeight ?? 0,
        users: []
      };
    }

    if (team.user) {
      response[team.team.id].users.push({
        uuid: team.user.uuid,
        dead: team.death != null
      });
    }
  }

  return new Response(JSON.stringify(Object.values(response)));
};
